==> unibeautify-0.14.0.tgz: package/README.md <==
# Unibeautify

[![Greenkeeper badge](https://badges.greenkeeper.io/Unibeautify/unibeautify.svg)](https://greenkeeper.io/)
[![Maintainability](https://api.codeclimate.com/v1/badges/b472e3d8388e14a6d9ea/maintainability)](https://codeclimate.com/github/Unibeautify/unibeautify/maintainability)

> One Beautifier to rule them all, One Beautifier to clean them, One Beautifier to bring them all and in the darkness sheen them

| Travis CI (Linux / macOS) | AppVeyor (Windows) | Test Coverage |
| --- | --- | --- |
| [![Build Status](https://travis-ci.org/Unibeautify/unibeautify.svg?branch=master)](https://travis-ci.org/Unibeautify/unibeautify) | [![Build status](https://ci.appveyor.com/api/projects/status/fsa9xirkn73hfibt/branch/master?svg=true)](https://ci.appveyor.com/project/Glavin001/unibeautify/branch/master) | [![Test Coverage](https://api.codeclimate.com/v1/badges/b472e3d8388e14a6d9ea/test_coverage)](https://codeclimate.com/github/Unibeautify/unibeautify/test_coverage) |


## Why
- Single beautifier abstracting multiple beautifiers for multiple languages
- Unified beautifier configuration options

## Install

To use programmatically with Node.js:

```bash
$ npm install --save unibeautify
```

### CLI

See [`Unibeautify-CLI`](https://github.com/Unibeautify/unibeautify-cli):

```bash
$ npm install --global unibeautify-cli
```

## Usage

See [`test/` directory](https://github.com/Unibeautify/unibeautify/tree/master/test) for examples.

## Contribute

```bash
# Be sure to lint
npm run lint
# And compile
npm run compile
# And test
npm test
```

==> unibeautify-0.15.0.tgz: package/README.md <==
# Unibeautify

[![Greenkeeper badge](https://badges.greenkeeper.io/Unibeautify/unibeautify.svg)](https://greenkeeper.io/)
[![Maintainability](https://api.codeclimate.com/v1/badges/b472e3d8388e14a6d9ea/maintainability)](https://codeclimate.com/github/Unibeautify/unibeautify/maintainability)

> One Beautifier to rule them all, One Beautifier to clean them, One Beautifier to bring them all and in the darkness sheen them

| Travis CI (Linux / macOS) | AppVeyor (Windows) | Test Coverage |
| --- | --- | --- |
| [![Build Status](https://travis-ci.com/Unibeautify/unibeautify.svg?branch=master)](https://travis-ci.com/Unibeautify/unibeautify) | [![Build status](https://ci.appveyor.com/api/projects/status/fsa9xirkn73hfibt/branch/master?svg=true)](https://ci.appveyor.com/project/Glavin001/unibeautify/branch/master) | [![Test Coverage](https://api.codeclimate.com/v1/badges/b472e3d8388e14a6d9ea/test_coverage)](https://codeclimate.com/github/Unibeautify/unibeautify/test_coverage) |


## Why
- Single beautifier abstracting multiple beautifiers for multiple languages
- Unified beautifier configuration options

## Install

To use programmatically with Node.js:

```bash
$ npm install --save unibeautify
```

### CLI

See [`Unibeautify-CLI`](https://github.com/Unibeautify/unibeautify-cli):

```bash
$ npm install --global unibeautify-cli
```

## Usage

See [`test/` directory](https://github.com/Unibeautify/unibeautify/tree/master/test) for examples.

## Contribute

```bash
# Be sure to lint
npm run lint
# And build
npm run build
# And test
npm test
```
